# Changelog

This project's full changelog is maintained in the GitHub releases page.

For a comprehensive list of changes, new features, and bug fixes, please visit: https://github.com/ANNUBS/neurogym/releases.

This page includes:

- Detailed release notes for each version
- Summary of changes
- Links to relevant issues and pull requests

For any questions or to report issues, please use the [GitHub issues page](https://github.com/ANNUBS/neurogym/issues).
